sequencetools.Tree
==================

.. abjad-lineage:: abjad.tools.sequencetools.Tree.Tree.Tree

.. autoclass:: abjad.tools.sequencetools.Tree.Tree.Tree
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.children
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.depth
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.index_in_parent
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.level
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.negative_level
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.position
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.root
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.storage_format
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Tree.Tree.Tree.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_next_n_complete_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_node_at_position
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.get_position_of_descendant
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.is_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_at_level
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_depth_first
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.iterate_payload
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.remove
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.remove_to_root
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.to_nested_lists
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__contains__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__ge__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__gt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__le__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__len__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__lt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__repr__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Tree.Tree.Tree.__str__
   :noindex:
